import { ExecuteJsProps, ExecuteJsResponse, FormattedMultipleAccs, GetSessionSigsProps, GetSignSessionKeySharesProp, JsonAuthSig, JsonEncryptionRetrieveRequest, JsonExecutionRequest, JsonSaveEncryptionKeyRequest, JsonSigningRetrieveRequest, JsonStoreSigningRequest, NodeShare, RejectedNodePromises, SignedChainDataToken, SignSessionKeyProp, SignWithECDSA, SuccessNodePromises, SupportedJsonRequests, ValidateAndSignECDSA } from '@litprotocol-dev/constants';
import { SiweMessage } from 'lit-siwe';
declare global {
    var litNodeClient: LitNodeClient;
}
declare const LitNodeClient_base: {
    new (...args: any): {
        [x: string]: any;
        config: import("@litprotocol-dev/constants").LitNodeClientConfig;
        connectedNodes: any;
        serverKeys: any;
        ready: boolean;
        subnetPubKey: string | null;
        networkPubKey: string | null;
        networkPubKeySet: string | null;
        overrideConfigsFromLocalStorage: () => void;
        setCustomBootstrapUrls: () => void;
    };
} & {
    new (...args: any[]): {
        [x: string]: any;
        getAuthSigOrSessionAuthSig: ({ authSig, sessionSigs, url, }: {
            authSig: any;
            sessionSigs: any;
            url: string;
        }) => any;
        getLitActionRequestBody: (params: ExecuteJsProps) => JsonExecutionRequest;
        getJWTParams: () => {
            iat: number;
            exp: number;
        };
        parseResponses: (responseString: string) => any;
        getSessionKey: (supposedSessionKey?: string | undefined) => import("@litprotocol-dev/constants").SessionKeyPair;
        getSessionCapabilities: (capabilities: any[], resources: any[]) => any[];
        getExpiration: () => string;
        getWalletSig: ({ authNeededCallback, chain, capabilities, switchChain, expiration, sessionKeyUri, }: {
            authNeededCallback: any;
            chain: string;
            capabilities: any[];
            switchChain: boolean;
            expiration: string;
            sessionKeyUri: string;
        }) => Promise<JsonAuthSig>;
        checkNeedToResignSessionKey: ({ siweMessage, walletSignature, sessionKeyUri, resources, sessionCapabilities, }: {
            siweMessage: SiweMessage;
            walletSignature: any;
            sessionKeyUri: any;
            resources: any;
            sessionCapabilities: any[];
        }) => Promise<boolean>;
    };
} & {
    new (...args: any[]): {
        [x: string]: any;
        sendCommandToNode: ({ url, data, }: import("@litprotocol-dev/constants").SendNodeCommand) => Promise<any>;
        getJsExecutionShares: (url: string, params: JsonExecutionRequest) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        getChainDataSigningShare: (url: string, params: import("@litprotocol-dev/constants").JsonSignChainDataRequest) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        getSigningShare: (url: string, params: JsonSigningRetrieveRequest) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        getDecryptionShare: (url: string, params: JsonEncryptionRetrieveRequest) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        storeSigningConditionWithNode: (url: string, params: import("@litprotocol-dev/constants").JsonSigningStoreRequest) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        storeEncryptionConditionWithNode: (url: string, params: import("@litprotocol-dev/constants").JsonSigningStoreRequest) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        signECDSA: (url: string, params: SignWithECDSA) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        signConditionEcdsa: (url: string, params: import("@litprotocol-dev/constants").SingConditionECDSA) => Promise<import("@litprotocol-dev/constants").NodeCommandResponse>;
        handshakeWithSgx: (params: import("@litprotocol-dev/constants").HandshakeWithSgx) => Promise<import("@litprotocol-dev/constants").NodeCommandServerKeysResponse>;
    };
} & {
    new (): {};
};
/** ---------- Main Export Class ---------- */
export declare class LitNodeClient extends LitNodeClient_base {
    /**
     *
     * Combine Shares from network public key set and signature shares
     *
     * @param { string } networkPubKeySet
     * @param { any } signatureShares
     *
     * @returns { string } final JWT (convert the sig to base64 and append to the jwt)
     *
     */
    combineSharesAndGetJWT: (networkPubKeySet: string, signatureShares: Array<NodeShare>) => string;
    /**
     *
     * Get different formats of access control conditions, eg. evm, sol, unified etc.
     *
     * @param { SupportedJsonRequests } params
     *
     * @returns { FormattedMultipleAccs }
     *
     */
    getFormattedAccessControlConditions: (params: SupportedJsonRequests) => FormattedMultipleAccs;
    /**
     *
     * Get hash of access control conditions
     *
     * @param { JsonStoreSigningRequest } params
     *
     * @returns { Promise<ArrayBuffer | undefined> }
     *
     */
    getHashedAccessControlConditions: (params: JsonStoreSigningRequest) => Promise<ArrayBuffer | undefined>;
    /**
     *
     * Get and gather node promises
     *
     * @param { any } callback
     *
     * @returns { Array<Promise<any>> }
     *
     */
    getNodePromises: (callback: Function) => Array<Promise<any>>;
    /**
     * Handle node promises
     *
     * @param { Array<Promise<any>> } nodePromises
     *
     * @returns { Promise<SuccessNodePromises | RejectedNodePromises> }
     *
     */
    handleNodePromises: (nodePromises: Array<Promise<any>>) => Promise<SuccessNodePromises | RejectedNodePromises>;
    /**
     *
     * Throw node error
     *
     * @param { RejectedNodePromises } res
     *
     * @returns { void }
     *
     */
    throwNodeError: (res: RejectedNodePromises) => void;
    /**
     *
     * Get signatures from signed data
     *
     * @param { Array<any> } signedData
     *
     * @returns { any }
     *
     */
    getSessionSignatures: (signedData: Array<any>) => any;
    /**
     *
     * Get signatures from signed data
     *
     * @param { Array<any> } signedData
     *
     * @returns { any }
     *
     */
    getSignatures: (signedData: Array<any>) => any;
    /**
     *
     * Get the decryptions from the decrypted data list
     *
     * @param { Array<any> } decryptedData
     *
     * @returns { Promise<Array<any>> }
     *
     */
    getDecryptions: (decryptedData: Array<any>) => Promise<Array<any>>;
    /**
     *
     * Get a single signature
     *
     * @param { Array<any> } shareData from all node promises
     *
     * @returns { string } signature
     *
     */
    getSignature: (shareData: Array<any>) => Promise<any>;
    /**
     *
     * Execute JS on the nodes and combine and return any resulting signatures
     *
     * @param { ExecuteJsRequest } params
     *
     * @returns { ExecuteJsResponse }
     *
     */
    executeJs: (params: ExecuteJsProps) => Promise<ExecuteJsResponse | undefined>;
    /**
     *
     * Request a signed JWT of any solidity function call from the LIT network.  There are no prerequisites for this function.  You should use this function if you need to transmit information across chains, or from a blockchain to a centralized DB or server.  The signature of the returned JWT verifies that the response is genuine.
     *
     * @param { SignedChainDataToken } params
     *
     * @returns { Promise<string | undefined>}
     */
    getSignedChainDataToken: (params: SignedChainDataToken) => Promise<string | undefined>;
    /**
     *
     * Request a signed JWT from the LIT network. Before calling this function, you must either create or know of a resource id and access control conditions for the item you wish to gain authorization for. You can create an access control condition using the saveSigningCondition function.
     *
     * @param { JsonSigningRetrieveRequest } params
     *
     * @returns { Promise<string> } final JWT
     *
     */
    getSignedToken: (params: JsonSigningRetrieveRequest) => Promise<string | undefined>;
    /**
     *
     * Associated access control conditions with a resource on the web.  After calling this function, users may use the getSignedToken function to request a signed JWT from the LIT network.  This JWT proves that the user meets the access control conditions, and is authorized to access the resource you specified in the resourceId parameter of the saveSigningCondition function.
     *
     * @param { JsonStoreSigningRequest } params
     *
     * @returns { Promise<boolean | undefined }
     *
     */
    saveSigningCondition: (params: JsonStoreSigningRequest) => Promise<boolean | undefined>;
    /**
     *
     * Retrieve the symmetric encryption key from the LIT nodes.  Note that this will only work if the current user meets the access control conditions specified when the data was encrypted.  That access control condition is typically that the user is a holder of the NFT that corresponds to this encrypted data.  This NFT token address and ID was specified when this LIT was created.
     *
     */
    getEncryptionKey: (params: JsonEncryptionRetrieveRequest) => Promise<Uint8Array | undefined>;
    /**
     *
     * Securely save the association between access control conditions and something that you wish to decrypt
     *
     * @param { JsonSaveEncryptionKeyRequest } params
     *
     * @returns { Promise<Uint8Array | undefined }
     *
     */
    saveEncryptionKey: (params: JsonSaveEncryptionKeyRequest) => Promise<Uint8Array | undefined>;
    /**
     *
     * Signs a message with Lit threshold ECDSA algorithms.
     *
     * @param { SignWithECDSA } params
     *
     * @returns { Promise<string> }
     *
     */
    signWithEcdsa: (params: SignWithECDSA) => Promise<string>;
    /**
     *
     * Validates a condition, and then signs the condition if the validation returns true.
     * Before calling this function, you must know the on chain conditions that you wish to validate.
     *
     * @param { ValidateAndSignECDSA } params
     *
     * @returns { Promise<string> }
     */
    validateAndSignEcdsa: (params: ValidateAndSignECDSA) => Promise<string | undefined>;
    /**
     *
     * Connect to the LIT nodes
     *
     * @returns { Promise } A promise that resolves when the nodes are connected.
     *
     */
    connect: () => Promise<any>;
    /** ============================== SESSION ============================== */
    /**
     * Sign a session key using a PKP
     * @returns {Object} An object containing the resulting signature.
     */
    signSessionKey: (params: SignSessionKeyProp) => Promise<JsonAuthSig>;
    getSignSessionKeyShares: (url: string, params: GetSignSessionKeySharesProp) => Promise<any>;
    /**
     * Get session signatures for a set of resources
     *
     * High level, how this works:
     * 1. Generate or retrieve session key
     * 2. Generate or retrieve the wallet signature of the session key
     * 3. Sign the specific resources with the session key
     *
     * @param { GetSessionSigsProps } params
     */
    getSessionSigs: (params: GetSessionSigsProps) => Promise<any>;
}
export {};
