"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseMixin = void 0;
const constants_1 = require("@litprotocol-dev/constants");
const misc_1 = require("@litprotocol-dev/misc");
const misc_browser_1 = require("@litprotocol-dev/misc-browser");
function BaseMixin(base) {
    return class extends base {
        // ========== Constructor ==========
        constructor(...args) {
            super();
            // ========== Scoped Class Helpers ==========
            /**
             *
             * (Browser Only) Get the config from browser local storage and override default config
             *
             * @returns { void }
             *
             */
            this.overrideConfigsFromLocalStorage = () => {
                if ((0, misc_1.isNode)())
                    return;
                const storageKey = 'LitNodeClientConfig';
                const storageConfigOrError = (0, misc_browser_1.getStorageItem)(storageKey);
                // -- validate
                if (storageConfigOrError.type === 'ERROR') {
                    console.warn(`Storage key "${storageKey}" is missing. `);
                    return;
                }
                // -- execute
                const storageConfig = JSON.parse(storageConfigOrError.result);
                // this.config = override(this.config, storageConfig);
                this.config = { ...this.config, ...storageConfig };
            };
            /**
             *
             * Set bootstrapUrls to match the network litNetwork unless it's set to custom
             *
             * @returns { void }
             *
             */
            this.setCustomBootstrapUrls = () => {
                // -- validate
                if (this.config.litNetwork === 'custom')
                    return;
                // -- execute
                const hasNetwork = this.config.litNetwork in constants_1.LIT_NETWORKS;
                if (!hasNetwork) {
                    // network not found, report error
                    (0, misc_1.throwError)({
                        message: 'the litNetwork specified in the LitNodeClient config not found in LIT_NETWORKS',
                        error: constants_1.LIT_ERROR.LIT_NODE_CLIENT_BAD_CONFIG_ERROR,
                    });
                    return;
                }
                this.config.bootstrapUrls = constants_1.LIT_NETWORKS[this.config.litNetwork];
            };
            let customConfig = args[0];
            console.log('Creating litNodeClient and customConfig is ', customConfig);
            // -- initialize default config
            this.config = constants_1.defaultLitnodeClientConfig;
            // -- if config params are specified, replace it
            if (customConfig) {
                this.config = { ...this.config, ...customConfig };
                // this.config = override(this.config, customConfig);
            }
            // -- init default properties
            this.connectedNodes = new Set();
            this.serverKeys = {};
            this.ready = false;
            this.subnetPubKey = null;
            this.networkPubKey = null;
            this.networkPubKeySet = null;
            // -- override configs
            this.overrideConfigsFromLocalStorage();
            // -- set bootstrapUrls to match the network litNetwork unless it's set to custom
            this.setCustomBootstrapUrls();
            // -- set global variables
            globalThis.litConfig = this.config;
        }
    };
}
exports.BaseMixin = BaseMixin;
//# sourceMappingURL=base-mixin.js.map