import { ExecuteJsProps, JsonAuthSig, JsonExecutionRequest, SessionKeyPair } from '@litprotocol-dev/constants';
import { SiweMessage } from 'lit-siwe';
import { Class } from './mixin';
export declare function HelperMixin<Base extends Class>(base: Base): {
    new (...args: any[]): {
        [x: string]: any;
        /**
         *
         * Get either auth sig or session auth sig
         *
         */
        getAuthSigOrSessionAuthSig: ({ authSig, sessionSigs, url, }: {
            authSig: JsonAuthSig | any;
            sessionSigs: any;
            url: string;
        }) => any;
        /**
         *
         * Get the request body of the lit action
         *
         * @param { ExecuteJsProps } params
         *
         * @returns { JsonExecutionRequest }
         *
         */
        getLitActionRequestBody: (params: ExecuteJsProps) => JsonExecutionRequest;
        /**
         *
         * we need to send jwt params iat (issued at) and exp (expiration) because the nodes may have different wall clock times, the nodes will verify that these params are withing a grace period
         *
         */
        getJWTParams: () => {
            iat: number;
            exp: number;
        };
        /**
         *
         * Parse the response string to JSON
         *
         * @param { string } responseString
         *
         * @returns { any } JSON object
         *
         */
        parseResponses: (responseString: string) => any;
        /**
         *
         * Try to get the session key in the local storage,
         * if not, generates one.
         * @param { string } supposedSessionKey
         * @return { }
         */
        getSessionKey: (supposedSessionKey?: string) => SessionKeyPair;
        /**
         *
         * Get session capabilities from user, it not, generates one
         * @param { Array<any> } capabilities
         * @param { Array<any> } resources
         * @return { Array<any> }
         */
        getSessionCapabilities: (capabilities: Array<any>, resources: Array<any>) => Array<any>;
        /**
         *
         * Get expiration for session
         *
         */
        getExpiration: () => string;
        /**
         *
         * Get the signature from local storage, if not, generates one
         *
         */
        getWalletSig: ({ authNeededCallback, chain, capabilities, switchChain, expiration, sessionKeyUri, }: {
            authNeededCallback: any;
            chain: string;
            capabilities: Array<any>;
            switchChain: boolean;
            expiration: string;
            sessionKeyUri: string;
        }) => Promise<JsonAuthSig>;
        /**
         *
         * Check if a session key needs to be resigned
         *
         */
        checkNeedToResignSessionKey: ({ siweMessage, walletSignature, sessionKeyUri, resources, sessionCapabilities, }: {
            siweMessage: SiweMessage;
            walletSignature: any;
            sessionKeyUri: any;
            resources: any;
            sessionCapabilities: Array<any>;
        }) => Promise<boolean>;
    };
} & Base;
