import { HandshakeWithSgx, JsonEncryptionRetrieveRequest, JsonExecutionRequest, JsonSignChainDataRequest, JsonSigningRetrieveRequest, JsonSigningStoreRequest, NodeCommandResponse, NodeCommandServerKeysResponse, SendNodeCommand, SignWithECDSA, SingConditionECDSA } from '@litprotocol-dev/constants';
import { Class } from './mixin';
export declare function NodeAPIsMixin<Base extends Class>(base: Base): {
    new (...args: any[]): {
        [x: string]: any;
        /**
         *
         * Send a command to nodes
         *
         * @param { SendNodeCommand }
         *
         * @returns { Promise<any> }
         *
         */
        sendCommandToNode: ({ url, data, }: SendNodeCommand) => Promise<any>;
        /**
         *
         * Get JS Execution Shares from Nodes
         *
         * @param { JsonExecutionRequest } params
         *
         * @returns { Promise<any> }
         */
        getJsExecutionShares: (url: string, params: JsonExecutionRequest) => Promise<NodeCommandResponse>;
        /**
         *
         * Get Chain Data Signing Shares
         *
         * @param { string } url
         * @param { JsonSignChainDataRequest } params
         *
         * @returns { Promise<any> }
         *
         */
        getChainDataSigningShare: (url: string, params: JsonSignChainDataRequest) => Promise<NodeCommandResponse>;
        /**
         *
         * Get Signing Shares from Nodes
         *
         * @param { string } url
         * @param { JsonSigningRetrieveRequest } params
         *
         * @returns { Promise<any>}
         *
         */
        getSigningShare: (url: string, params: JsonSigningRetrieveRequest) => Promise<NodeCommandResponse>;
        /**
         *
         * Ger Decryption Shares from Nodes
         *
         * @param { string } url
         * @param { JsonEncryptionRetrieveRequest } params
         *
         * @returns { Promise<any> }
         *
         */
        getDecryptionShare: (url: string, params: JsonEncryptionRetrieveRequest) => Promise<NodeCommandResponse>;
        /**
         *
         * Store signing conditions to nodes
         *
         * @param { string } url
         * @param { JsonSigningStoreRequest } params
         *
         * @returns { Promise<NodeCommandResponse> }
         *
         */
        storeSigningConditionWithNode: (url: string, params: JsonSigningStoreRequest) => Promise<NodeCommandResponse>;
        /**
         *
         * Store encryption conditions to nodes
         *
         * @param { string } urk
         * @param { JsonEncryptionStoreRequest } params
         *
         * @returns { Promise<NodeCommandResponse> }
         *
         */
        storeEncryptionConditionWithNode: (url: string, params: JsonSigningStoreRequest) => Promise<NodeCommandResponse>;
        /**
         *
         * Sign wit ECDSA
         *
         * @param { string } url
         * @param { SignWithECDSA } params
         *
         * @returns { Promise}
         *
         */
        signECDSA: (url: string, params: SignWithECDSA) => Promise<NodeCommandResponse>;
        /**
         *
         * Sign Condition ECDSA
         *
         * @param { string } url
         * @param { SignConditionECDSA } params
         *
         * @returns { Promise<NodeCommandResponse> }
         *
         */
        signConditionEcdsa: (url: string, params: SingConditionECDSA) => Promise<NodeCommandResponse>;
        /**
         *
         * Handshake with SGX
         *
         * @param { HandshakeWithSgx } params
         *
         * @returns { Promise<NodeCommandServerKeysResponse> }
         *
         */
        handshakeWithSgx: (params: HandshakeWithSgx) => Promise<NodeCommandServerKeysResponse>;
    };
} & Base;
